#!/bin/bash

# QA Jenkins Jobs
# Copyright 2016 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

# Convenience script for flashing Ubuntu phones
# and making common configurations.
#
# I've been using this personally for a while, and it's helpful.
# Added it to power tests to separate out the flashing code from the rest.

# extract device name from node name (there's probably a more sh way to do this)
export DEVICE=$(echo $NODE_NAME | sed 's/\(\w\)-.*/\1/')

# need plars' lifeboat scripts to get our adb serial
rm -rf lifeboat
if [ -z LIFEBOAT_BRANCH ]; then
    LIFEBOAT_BRANCH="https://git.launchpad.net/~canonical-hw-cert/lifeboat"
fi
git clone $LIFEBOAT_BRANCH
export ANDROID_SERIAL=$(./lifeboat/get-device-info serial $NODE_NAME)

export PASSWD="0000"
export DEVMODE="--developer-mode --password=$PASSWD"
export DEFAULT_CHANNEL="ubuntu-touch/devel-proposed"

# Figure out the channel and other options based on the phone type
echo "Device: $DEVICE"
if [ x"$REVISION" != x ]; then
  echo "Revision: $REVISION"
  REVARGS="--revision=$REVISION"
fi

case x"$DEVICE" in
  x"mako")
    FASTBOOT=no
    ;;
  x"krillin")
    DEFAULT_CHANNEL="ubuntu-touch/rc-proposed/bq-aquaris.en"
    FASTBOOT=yes
    RECOVERY="--recovery-image ${WORKSPACE}/recovery.img"
    ;;
  x"m75" | x"arale")
    DEVICE=arale
    DEFAULT_CHANNEL="ubuntu-touch/rc-proposed/meizu.en"
    FASTBOOT=yes
    RECOVERY="--recovery-image ${WORKSPACE}/recovery.img"
    ;;
  *)
    echo "Unrecognized device: $DEVICE"
    exit 1
esac

if [ -z "$CHANNEL" ]; then
  CHANNEL=$DEFAULT_CHANNEL
fi

# Summarize what we're going to do
echo "Server: $SERVER"
echo "Channel: $CHANNEL"
echo "Wifi: $WIFI"
echo "Fastboot: $FASTBOOT"
echo "Recovery: $RECOVERY"
QUERY_CMD="ubuntu-device-flash $SERVER $REVARGS query --channel=$CHANNEL --device $DEVICE --show-image"
echo $QUERY_CMD
$QUERY_CMD

rootcmd () {
  adb -s $ANDROID_SERIAL shell "echo $PASSWD | sudo -S $*"
}

# Handle fastboot mode and fastboot recovery mode
if [ x"$FASTBOOT_RECOVERY" != x ]; then
  echo 'Rebooting to bootloader/fastboot'
  adb -s $ANDROID_SERIAL reboot bootloader
  sleep 10
  echo "Flashing recovery image $FASTBOOT_RECOVERY"
  fastboot -s $ANDROID_SERIAL flash recovery $FASTBOOT_RECOVERY
  echo "Rebooting into recovery"
  fastboot -s $ANDROID_SERIAL boot $FASTBOOT_RECOVERY
  sleep 10
  FASTBOOT=no
elif [ x"$FASTBOOT" = xyes ]; then
  EXTRA="--bootstrap"
  echo 'Rebooting to bootloader/fastboot'
  adb -s $ANDROID_SERIAL reboot bootloader
  sleep 10
fi

echo 'flashing device'
FLASH_CMD="ubuntu-device-flash $SERVER $REVARGS touch --serial=$ANDROID_SERIAL --channel=$CHANNEL --device $DEVICE $DEVMODE $RECOVERY --wipe $EXTRA"
echo $FLASH_CMD
$FLASH_CMD

echo 'waiting for device to boot'
adb -s $ANDROID_SERIAL wait-for-device
echo 'waiting a few seconds for boot'
sleep 5

# setup network; location of config per plars' advice
DEFAULT_NETWORK_CONFIG_PATH="/var/lib/jenkins/.ubuntu-ci/wifi.conf"
if [ -n NETWORK_CONFIG_PATH ]; then
  NETWORK_CONFIG_PATH=$DEFAULT_NETWORK_CONFIG_PATH
fi
phablet-network -n $NETWORK_CONFIG_PATH

# Disable the welcome wizard
if [ x"$WIZARD" = x"no" ]; then
  echo 'disabling wizard'
  phablet-config -s $ANDROID_SERIAL welcome-wizard --disable
  adb -s $ANDROID_SERIAL wait-for-device
  REBOOT_NEEDED=yes
fi

# Disable the edges intro
if [ x"$EDGEINTRO" = x"no" ]; then
  echo 'disabling edges intro'
  phablet-config -s $ANDROID_SERIAL edges-intro --disable
  adb -s $ANDROID_SERIAL wait-for-device
fi

if [ x"$REBOOT_NEEDED" = x"yes" ]; then
  echo 'rebooting to activate previous changes'
  adb -s $ANDROID_SERIAL reboot
  adb -s $ANDROID_SERIAL wait-for-device
fi

# wait until our network is ready
echo "Checking device network connection..."
RETRY=0;
until wget -q --spider launchpad.net || [ $RETRY -gt 30 ]; do
  sleep 1
  RETRY=$(($RETRY+1))
  echo "wget attempt $RETRY failed, trying again..."
done
if [ $RETRY -gt 30 ]; then
  echo 'Device has no network connection!'
  exit 1
fi
