#!/bin/bash

set -x
set -e

export SUBUNIT_RESULTS_PATH=$1
export TEST_LEVEL=$2
export LABEL=$3

rm -rf qakit
bzr branch lp:qakit -r30
cd qakit

virtualenv --python=python3 ve3
. ve3/bin/activate
python3 setup.py develop

bzr cat "$UBUNTU_SYSTEM_TESTS_CONFIG_BRANCH/practitest/config.ini" > config.ini

upload_system_practitest () {
  adb -s $ANDROID_SERIAL shell system-image-cli -i | tr '\r' ' ' > VERSION_INFO
  export IMAGE=$(grep "version version" VERSION_INFO | sed 's/^version version: //;s/ $//')
  export DEVICE=$(grep "device name" VERSION_INFO | sed 's/^device name: \(.\)/\u\1/;s/ $//')
  export RELEASE_NUMBER=$(adb shell lsb_release -rs | tr -d '\r')
  export RELEASE_NAME=$(adb shell lsb_release -cs | tr -d '\r')
  TEST_LEVEL_LOWER=$1
  TEST_LEVEL_UPPER=$(echo $1 | sed 's/^\(.\)/\u\1/')
  SUFFIX=$2
  SUBUNIT_FILE=$3

  if [ $1 = "sanity" ] ; then
    export MANUAL="--manual=${TEST_LEVEL_UPPER}/${DEVICE}"
  else
    export MANUAL=""
  fi

  subunit-practitest-export $SUBUNIT_FILE create "${TEST_LEVEL_LOWER}-${DEVICE}-${RELEASE_NAME}-${IMAGE}-${SUFFIX}" ${DEVICE} ${TEST_LEVEL_UPPER} ${RELEASE_NUMBER} ${IMAGE} "'$(adb shell system-image-cli -i)'" ${MANUAL}

}

# this enables HTTP to the outside world (e.g. PractiTest) as managed by IS
export https_proxy="https://squid.internal:3128/"

# looks like:
# upload_system_practitest sanity uk "${WORKSPACE}/foo/test-results.subunit"
upload_system_practitest ${TEST_LEVEL} ${LABEL} ${SUBUNIT_RESULTS_PATH}

unset https_proxy
deactivate
